flutter_barcode_sdk library
Classes
- BarcodeFormat
- Defines supported barcode format constants for use with FlutterBarcodeSdk.setBarcodeFormats.
- BarcodeResult
- Represents the result of a barcode scan, including format, text, coordinates, and angle.
- FlutterBarcodeSdk
- A Flutter plugin for barcode scanning using the Dynamsoft Barcode Reader SDK.
Enums
- ImagePixelFormat
- Defines the supported image pixel formats.
- ImageRotation
- Defines image rotation angles in degrees.
Functions
-
convertResults(
List< Map> jsonResults) → List<BarcodeResult> - Converts a list of barcode scan results from JSON format to BarcodeResult objects.